lots = """
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls0/r1i4p6/hfls0_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls1/r1i4p6/hfls1_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls10/r1i4p6/hfls10_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls100/r1i4p6/hfls100_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls101/r1i4p6/hfls101_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls102/r1i4p6/hfls102_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls103/r1i4p6/hfls103_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls104/r1i4p6/hfls104_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls105/r1i4p6/hfls105_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls106/r1i4p6/hfls106_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls107/r1i4p6/hfls107_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls108/r1i4p6/hfls108_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls109/r1i4p6/hfls109_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls11/r1i4p6/hfls11_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls110/r1i4p6/hfls110_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls111/r1i4p6/hfls111_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls112/r1i4p6/hfls112_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls113/r1i4p6/hfls113_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls114/r1i4p6/hfls114_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls115/r1i4p6/hfls115_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls116/r1i4p6/hfls116_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls117/r1i4p6/hfls117_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls118/r1i4p6/hfls118_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls119/r1i4p6/hfls119_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls12/r1i4p6/hfls12_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls120/r1i4p6/hfls120_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls121/r1i4p6/hfls121_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls122/r1i4p6/hfls122_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls123/r1i4p6/hfls123_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls124/r1i4p6/hfls124_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls125/r1i4p6/hfls125_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls126/r1i4p6/hfls126_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls127/r1i4p6/hfls127_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls128/r1i4p6/hfls128_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls129/r1i4p6/hfls129_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls13/r1i4p6/hfls13_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls130/r1i4p6/hfls130_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls131/r1i4p6/hfls131_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls132/r1i4p6/hfls132_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls133/r1i4p6/hfls133_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls134/r1i4p6/hfls134_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls135/r1i4p6/hfls135_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls136/r1i4p6/hfls136_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls137/r1i4p6/hfls137_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls138/r1i4p6/hfls138_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls139/r1i4p6/hfls139_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls14/r1i4p6/hfls14_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls140/r1i4p6/hfls140_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls141/r1i4p6/hfls141_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls142/r1i4p6/hfls142_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls143/r1i4p6/hfls143_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls144/r1i4p6/hfls144_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls145/r1i4p6/hfls145_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls146/r1i4p6/hfls146_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls147/r1i4p6/hfls147_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls148/r1i4p6/hfls148_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls149/r1i4p6/hfls149_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls15/r1i4p6/hfls15_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls150/r1i4p6/hfls150_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls151/r1i4p6/hfls151_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls152/r1i4p6/hfls152_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls153/r1i4p6/hfls153_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls154/r1i4p6/hfls154_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls155/r1i4p6/hfls155_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls156/r1i4p6/hfls156_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls157/r1i4p6/hfls157_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls158/r1i4p6/hfls158_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls159/r1i4p6/hfls159_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls16/r1i4p6/hfls16_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls160/r1i4p6/hfls160_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls161/r1i4p6/hfls161_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls162/r1i4p6/hfls162_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls163/r1i4p6/hfls163_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls164/r1i4p6/hfls164_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls165/r1i4p6/hfls165_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls166/r1i4p6/hfls166_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls167/r1i4p6/hfls167_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls168/r1i4p6/hfls168_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls169/r1i4p6/hfls169_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls17/r1i4p6/hfls17_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls170/r1i4p6/hfls170_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls171/r1i4p6/hfls171_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls172/r1i4p6/hfls172_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls173/r1i4p6/hfls173_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls174/r1i4p6/hfls174_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls175/r1i4p6/hfls175_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls176/r1i4p6/hfls176_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls177/r1i4p6/hfls177_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls178/r1i4p6/hfls178_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls179/r1i4p6/hfls179_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls18/r1i4p6/hfls18_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls180/r1i4p6/hfls180_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls181/r1i4p6/hfls181_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls182/r1i4p6/hfls182_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls183/r1i4p6/hfls183_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls184/r1i4p6/hfls184_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls185/r1i4p6/hfls185_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls186/r1i4p6/hfls186_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls187/r1i4p6/hfls187_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls188/r1i4p6/hfls188_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls189/r1i4p6/hfls189_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls19/r1i4p6/hfls19_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls190/r1i4p6/hfls190_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls191/r1i4p6/hfls191_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls192/r1i4p6/hfls192_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls193/r1i4p6/hfls193_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls194/r1i4p6/hfls194_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls195/r1i4p6/hfls195_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls196/r1i4p6/hfls196_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls197/r1i4p6/hfls197_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls198/r1i4p6/hfls198_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls199/r1i4p6/hfls199_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls2/r1i4p6/hfls2_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls20/r1i4p6/hfls20_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls200/r1i4p6/hfls200_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls201/r1i4p6/hfls201_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls202/r1i4p6/hfls202_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls203/r1i4p6/hfls203_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls204/r1i4p6/hfls204_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls205/r1i4p6/hfls205_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls206/r1i4p6/hfls206_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls207/r1i4p6/hfls207_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls208/r1i4p6/hfls208_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls209/r1i4p6/hfls209_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls21/r1i4p6/hfls21_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls210/r1i4p6/hfls210_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls211/r1i4p6/hfls211_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls212/r1i4p6/hfls212_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls213/r1i4p6/hfls213_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls214/r1i4p6/hfls214_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls215/r1i4p6/hfls215_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls216/r1i4p6/hfls216_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls217/r1i4p6/hfls217_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls218/r1i4p6/hfls218_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls219/r1i4p6/hfls219_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls22/r1i4p6/hfls22_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls220/r1i4p6/hfls220_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls221/r1i4p6/hfls221_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls222/r1i4p6/hfls222_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls223/r1i4p6/hfls223_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls224/r1i4p6/hfls224_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls225/r1i4p6/hfls225_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls226/r1i4p6/hfls226_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls227/r1i4p6/hfls227_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls228/r1i4p6/hfls228_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls229/r1i4p6/hfls229_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls23/r1i4p6/hfls23_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls230/r1i4p6/hfls230_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls231/r1i4p6/hfls231_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls232/r1i4p6/hfls232_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls233/r1i4p6/hfls233_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls234/r1i4p6/hfls234_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls235/r1i4p6/hfls235_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls236/r1i4p6/hfls236_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls237/r1i4p6/hfls237_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls238/r1i4p6/hfls238_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls239/r1i4p6/hfls239_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls24/r1i4p6/hfls24_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls240/r1i4p6/hfls240_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls241/r1i4p6/hfls241_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls242/r1i4p6/hfls242_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls243/r1i4p6/hfls243_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls244/r1i4p6/hfls244_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls245/r1i4p6/hfls245_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls246/r1i4p6/hfls246_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls247/r1i4p6/hfls247_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls248/r1i4p6/hfls248_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls249/r1i4p6/hfls249_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls25/r1i4p6/hfls25_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls250/r1i4p6/hfls250_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls251/r1i4p6/hfls251_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls252/r1i4p6/hfls252_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls253/r1i4p6/hfls253_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls254/r1i4p6/hfls254_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls255/r1i4p6/hfls255_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls256/r1i4p6/hfls256_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls257/r1i4p6/hfls257_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls258/r1i4p6/hfls258_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls259/r1i4p6/hfls259_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls26/r1i4p6/hfls26_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls260/r1i4p6/hfls260_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls261/r1i4p6/hfls261_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls262/r1i4p6/hfls262_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls263/r1i4p6/hfls263_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls264/r1i4p6/hfls264_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls265/r1i4p6/hfls265_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls266/r1i4p6/hfls266_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls267/r1i4p6/hfls267_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls268/r1i4p6/hfls268_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls269/r1i4p6/hfls269_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls27/r1i4p6/hfls27_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls270/r1i4p6/hfls270_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls271/r1i4p6/hfls271_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls272/r1i4p6/hfls272_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls273/r1i4p6/hfls273_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls274/r1i4p6/hfls274_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls275/r1i4p6/hfls275_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls276/r1i4p6/hfls276_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls277/r1i4p6/hfls277_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls278/r1i4p6/hfls278_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls279/r1i4p6/hfls279_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls28/r1i4p6/hfls28_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls280/r1i4p6/hfls280_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls281/r1i4p6/hfls281_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls282/r1i4p6/hfls282_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls283/r1i4p6/hfls283_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls284/r1i4p6/hfls284_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls285/r1i4p6/hfls285_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls286/r1i4p6/hfls286_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls287/r1i4p6/hfls287_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls288/r1i4p6/hfls288_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls289/r1i4p6/hfls289_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls29/r1i4p6/hfls29_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls290/r1i4p6/hfls290_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls291/r1i4p6/hfls291_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls292/r1i4p6/hfls292_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls293/r1i4p6/hfls293_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls294/r1i4p6/hfls294_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls295/r1i4p6/hfls295_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls296/r1i4p6/hfls296_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls297/r1i4p6/hfls297_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls298/r1i4p6/hfls298_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls299/r1i4p6/hfls299_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls3/r1i4p6/hfls3_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls30/r1i4p6/hfls30_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls300/r1i4p6/hfls300_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls301/r1i4p6/hfls301_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls302/r1i4p6/hfls302_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls303/r1i4p6/hfls303_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls304/r1i4p6/hfls304_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls305/r1i4p6/hfls305_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls306/r1i4p6/hfls306_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls307/r1i4p6/hfls307_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls308/r1i4p6/hfls308_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls309/r1i4p6/hfls309_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls31/r1i4p6/hfls31_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls310/r1i4p6/hfls310_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls311/r1i4p6/hfls311_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls312/r1i4p6/hfls312_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls313/r1i4p6/hfls313_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls314/r1i4p6/hfls314_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls315/r1i4p6/hfls315_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls316/r1i4p6/hfls316_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls317/r1i4p6/hfls317_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls318/r1i4p6/hfls318_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls319/r1i4p6/hfls319_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls32/r1i4p6/hfls32_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls320/r1i4p6/hfls320_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls321/r1i4p6/hfls321_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls322/r1i4p6/hfls322_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls323/r1i4p6/hfls323_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls324/r1i4p6/hfls324_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls325/r1i4p6/hfls325_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls326/r1i4p6/hfls326_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls327/r1i4p6/hfls327_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls328/r1i4p6/hfls328_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls329/r1i4p6/hfls329_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls33/r1i4p6/hfls33_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls330/r1i4p6/hfls330_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls331/r1i4p6/hfls331_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls332/r1i4p6/hfls332_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls333/r1i4p6/hfls333_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls334/r1i4p6/hfls334_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls335/r1i4p6/hfls335_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls336/r1i4p6/hfls336_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls337/r1i4p6/hfls337_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls338/r1i4p6/hfls338_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls339/r1i4p6/hfls339_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls34/r1i4p6/hfls34_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls340/r1i4p6/hfls340_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls341/r1i4p6/hfls341_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls342/r1i4p6/hfls342_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls343/r1i4p6/hfls343_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls344/r1i4p6/hfls344_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls345/r1i4p6/hfls345_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls346/r1i4p6/hfls346_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls347/r1i4p6/hfls347_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls348/r1i4p6/hfls348_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls349/r1i4p6/hfls349_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls35/r1i4p6/hfls35_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls350/r1i4p6/hfls350_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls351/r1i4p6/hfls351_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls352/r1i4p6/hfls352_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls353/r1i4p6/hfls353_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls354/r1i4p6/hfls354_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls355/r1i4p6/hfls355_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls356/r1i4p6/hfls356_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls357/r1i4p6/hfls357_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls358/r1i4p6/hfls358_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls359/r1i4p6/hfls359_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls36/r1i4p6/hfls36_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls360/r1i4p6/hfls360_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls361/r1i4p6/hfls361_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls362/r1i4p6/hfls362_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls363/r1i4p6/hfls363_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls364/r1i4p6/hfls364_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls365/r1i4p6/hfls365_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls366/r1i4p6/hfls366_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls367/r1i4p6/hfls367_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls368/r1i4p6/hfls368_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls369/r1i4p6/hfls369_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls37/r1i4p6/hfls37_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls370/r1i4p6/hfls370_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls371/r1i4p6/hfls371_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls372/r1i4p6/hfls372_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls373/r1i4p6/hfls373_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls374/r1i4p6/hfls374_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls375/r1i4p6/hfls375_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls376/r1i4p6/hfls376_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls377/r1i4p6/hfls377_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls378/r1i4p6/hfls378_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls379/r1i4p6/hfls379_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls38/r1i4p6/hfls38_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls380/r1i4p6/hfls380_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls381/r1i4p6/hfls381_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls382/r1i4p6/hfls382_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls383/r1i4p6/hfls383_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls384/r1i4p6/hfls384_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls385/r1i4p6/hfls385_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls386/r1i4p6/hfls386_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls387/r1i4p6/hfls387_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls388/r1i4p6/hfls388_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls389/r1i4p6/hfls389_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls39/r1i4p6/hfls39_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls390/r1i4p6/hfls390_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls391/r1i4p6/hfls391_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls392/r1i4p6/hfls392_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls393/r1i4p6/hfls393_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls394/r1i4p6/hfls394_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls395/r1i4p6/hfls395_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls396/r1i4p6/hfls396_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls397/r1i4p6/hfls397_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls398/r1i4p6/hfls398_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls399/r1i4p6/hfls399_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls4/r1i4p6/hfls4_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls40/r1i4p6/hfls40_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls41/r1i4p6/hfls41_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls42/r1i4p6/hfls42_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls43/r1i4p6/hfls43_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls44/r1i4p6/hfls44_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls45/r1i4p6/hfls45_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls46/r1i4p6/hfls46_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls47/r1i4p6/hfls47_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls48/r1i4p6/hfls48_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls49/r1i4p6/hfls49_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls5/r1i4p6/hfls5_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls50/r1i4p6/hfls50_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls51/r1i4p6/hfls51_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls52/r1i4p6/hfls52_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls53/r1i4p6/hfls53_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls54/r1i4p6/hfls54_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls55/r1i4p6/hfls55_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls56/r1i4p6/hfls56_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls57/r1i4p6/hfls57_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls58/r1i4p6/hfls58_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls59/r1i4p6/hfls59_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls6/r1i4p6/hfls6_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls60/r1i4p6/hfls60_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls61/r1i4p6/hfls61_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls62/r1i4p6/hfls62_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls63/r1i4p6/hfls63_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls64/r1i4p6/hfls64_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls65/r1i4p6/hfls65_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls66/r1i4p6/hfls66_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls67/r1i4p6/hfls67_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls68/r1i4p6/hfls68_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls69/r1i4p6/hfls69_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls7/r1i4p6/hfls7_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls70/r1i4p6/hfls70_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls71/r1i4p6/hfls71_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls72/r1i4p6/hfls72_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls73/r1i4p6/hfls73_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls74/r1i4p6/hfls74_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls75/r1i4p6/hfls75_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls76/r1i4p6/hfls76_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls77/r1i4p6/hfls77_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls78/r1i4p6/hfls78_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls79/r1i4p6/hfls79_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls8/r1i4p6/hfls8_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls80/r1i4p6/hfls80_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls81/r1i4p6/hfls81_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls82/r1i4p6/hfls82_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls83/r1i4p6/hfls83_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls84/r1i4p6/hfls84_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls85/r1i4p6/hfls85_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls86/r1i4p6/hfls86_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls87/r1i4p6/hfls87_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls88/r1i4p6/hfls88_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls89/r1i4p6/hfls89_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls9/r1i4p6/hfls9_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls90/r1i4p6/hfls90_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls91/r1i4p6/hfls91_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls92/r1i4p6/hfls92_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls93/r1i4p6/hfls93_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls94/r1i4p6/hfls94_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls95/r1i4p6/hfls95_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls96/r1i4p6/hfls96_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls97/r1i4p6/hfls97_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls98/r1i4p6/hfls98_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls99/r1i4p6/hfls99_A1_pcmdi-08a_2xco2_r1i4p6_197901-197902.nc
""".split()

out = {
    'old_cmor_tables_climatology_test_code': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-01/2xco2/monClim/atm/tasDiurnal/r1i1p1/tasDiurnal_A1_pcmdi-01_2xco2_r1i1p1_203001-203003_clim.nc'],
    'old_cmor_tables_test_any_from_asc': ['IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-01a_2xco2_r1i1p1_187001-187003.nc'],
    'old_cmor_tables_test_any_from_asc_d': ['IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-01a_2xco2_r1i1p1_187001-187003.nc'],
    'old_cmor_tables_test_any_from_asc_i': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-08a_2xco2_r1i1p1_187001-187003.nc'],
    'old_cmor_tables_karls_test': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/cl/r1i1p1/cl_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atmosphere/hfls/r1i1p1/hfls_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/mrsos/r1i1p1/mrsos_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/ps/r1i1p1/ps_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/ta/r1i1p1/ta_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/tas/r1i1p1/tas_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a01/2xco2/mon/atm/ua/r1i1p1/ua_A1_pcmdi-a01_2xco2_r1i1p1_203001-203002.nc'],
    'old_cmor_tables_test1': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfls/r1i1p1/hfls_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc'],
    'old_cmor_tables_test2': ['IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/hfls/r1i1p1/hfls_2_pcmdi-01a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_2_pcmdi-01a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-01a_2xco2_r1i1p1_197901-197902_User-suffix-1979-2001.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-01a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-01a/2xco2/mon/atm/ua/r1i1p1/ua_2_pcmdi-01a_2xco2_r1i1p1_197901-197902_User-suffix-1979-2001.nc'],
    'old_cmor_tables_test3': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfls/r1i1p1/hfls_2_pcmdi-08a_2xco2_r1i1p1_197901-197902_1979-2001.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_2_pcmdi-08a_2xco2_r1i1p1_197901-197902_1979-2001.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_197901-197902_1979-2001.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-08a_2xco2_r1i1p1_197901-197902_1979-2001.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_2_pcmdi-08a_2xco2_r1i1p1_197901-197902_1979-2001.nc'],
    'old_cmor_tables_test4': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfls/r1i1p1/hfls_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                              'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc'],
    'old_cmor_tables_main_prog': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfls/r1i1p1/hfls_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                                  'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                                  'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                                  'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc',
                                  'IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_2_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc'],
    'old_cmor_tables_mytest_4d_r': ['IPCC/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-a08_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_rewrite_harvardf_data': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/20c3m/day/atm/tas/r1i1p1/tas_A_20c3m_r1i1p1_19920101-19920110.nc'],
    'old_cmor_tables_test_3h': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/3hr/atm/hfls/r1i1p1/hfls_A3_pcmdi-08a_2xco2_r1i1p1_2030010101-2030010104.nc',
                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/3hr/atm/pr/r1i1p1/pr_A3_pcmdi-08a_2xco2_r1i1p1_2030010101-2030010104.nc',
                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/3hr/atm/tas/r1i1p1/tas_A3_pcmdi-08a_2xco2_r1i1p1_2030010101-2030010104.nc'],
    'old_cmor_tables_test_dimensionless': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/cl/r1i1p1/cl_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/hfls/r1i1p1/hfls_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/mrsos/r1i1p1/mrsos_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/ps/r1i1p1/ps_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/ta/r1i1p1/ta_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/tas/r1i1p1/tas_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/tro3/r1i1p1/tro3_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc',
                                           'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-a08/2xco2/mon/atm/ua/r1i1p1/ua_A1_pcmdi-a08_2xco2_r1i1p1_203001-203002.nc'],
    'old_cmor_tables_test_fortran_example_00': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/cl/r1i1p1/cl_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls/r1i1p1/hfls_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ps/r1i1p1/ps_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc',
                                                'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002_ftn-00.nc'],
    'old_cmor_tables_test_fortran_example_01': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls/r1i1p1/hfls_A1_pcmdi-08a_2xco2_r1i1p1_198001-198002_ftn-01.nc', ],
    'old_cmor_tables_test_fortran_example_02': ['Test/IPCC_Fourth_Assessment/output/INSTITUTE_ID/mon/REALM/hfls/r1i1p1/hfls_A1_r1i1p1_203001-203002_ftn-02.nc',
                                                'Test/IPCC_Fourth_Assessment/output/INSTITUTE_ID/mon/REALM/mrsos/r1i1p1/mrsos_A1_r1i1p1_203001-203002_ftn-02.nc',
                                                'Test/IPCC_Fourth_Assessment/output/INSTITUTE_ID/mon/REALM/ps/r1i1p1/ps_A1_r1i1p1_203001-203002_ftn-02.nc',
                                                'Test/IPCC_Fourth_Assessment/output/INSTITUTE_ID/mon/REALM/tas/r1i1p1/tas_A1_r1i1p1_203001-203002_ftn-02.nc',
                                                ],
    'old_cmor_tables_test_station_data': [None],
    'old_cmor_tables_test_cmor_grid_alejandro': [None],
    'old_cmor_tables_test_sophie': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/fx/atmosphere/hfls/r0i0p0/hfls_A1_pcmdi-08a_r0i0p0.nc'],
    'old_cmor_tables_test_region': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfogo/r1i1p1/hfogo_O1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc'],
    'old_cmor_tables_test_sigma': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/cl/r1i1p1/cl_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/hfls/r1i1p1/hfls_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ps/r1i1p1/ps_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tro3/r1i1p1/tro3_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                   'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc'],
    'old_cmor_tables_test_singleton': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/cl/r1i1p1/cl_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls/r1i1p1/hfls_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/mrsos/r1i1p1/mrsos_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ps/r1i1p1/ps_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/tas/r1i1p1/tas_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc',
                                       'IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ua/r1i1p1/ua_A1_pcmdi-08a_2xco2_r1i1p1_203001-203002.nc'],
    'old_cmor_tables_mytest_4d_r_big_array': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_mytest_4d_d_big_array_2': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_mytest_4d_d_big_array_3': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_mytest_4d_d_big_array_4': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_mytest_4d_d_big_array_5': ['IPCC/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atm/ta/r1i1p1/ta_2_pcmdi-08a_2xco2_r1i1p1_194901-194903.nc'],
    'old_cmor_tables_test_lots_of_variables': lots,
    'old_cmor_tables_test_shrt_exp_nm_set_att_initi': ['IPCC_Fourth_Assessment/output/INSTITUTE_ID/pcmdi-08a/2xco2/mon/atmosphere/hfls0/r1i1p1/hfls0_A1_pcmdi-08a_2xco2_r1i1p1_197901-197902.nc'],
}



#****** Conflict with 'orog' in formula terms *****
import cmor
import numpy

error_flag = cmor.setup(inpath='Test', netcdf_file_action=cmor.CMOR_REPLACE)

error_flag = cmor.dataset_json("Test/CMOR_input_example.json")

# creates 1 degree grid
nlat = 180
nlon = 360
alats = numpy.arange(180) - 89.5
bnds_lat = numpy.arange(181) - 90
alons = numpy.arange(360) + .5
bnds_lon = numpy.arange(361)
cmor.load_table("Tables/CMIP6_Emon.json")
ilat = cmor.axis(
    table_entry='latitude',
    units='degrees_north',
    length=nlat,
    coord_vals=alats,
    cell_bounds=bnds_lat)

ilon = cmor.axis(
    table_entry='longitude',
    length=nlon,
    units='degrees_east',
    coord_vals=alons,
    cell_bounds=bnds_lon)

lev = 1
ntimes = 12
plevs = (numpy.arange(lev) + 1) * 1.E4


itim = cmor.axis(
    table_entry='time',
    units='months since 2030-1-1',
    length=ntimes,
    interval='1 month')

zlevs = numpy.array((0.1, ))
zlev_bnds = numpy.array((0., .2, ))
table_entry = 'hybrid_height'
if table_entry == 'hybrid_height':
    ilev = cmor.axis(
        table_entry='hybrid_height',
        # table_entry='standard_sigma',
        # table_entry='standard_hybrid_sigma',
        units='m',
        length=lev,
        coord_vals=zlevs,
        cell_bounds=zlev_bnds)

    p0 = 0.5e4
##   p0 = 1.e5
# a_coeff = (/ 0.1, 0.2, 0.3, 0.2, 0.1 /)
    a_coeff = numpy.array((0.2, ))
    b_coeff = numpy.array((0.0, ))

# a_coeff_bnds=(/0.,.15, .25, .25, .15, 0./)
    a_coeff_bnds = numpy.array((0., .3,))
    b_coeff_bnds = numpy.array((0., .05,))

# error_flag = cmor.zfactor(
# zaxis_id=ilev,
# zfactor_name='ptop',
# units='Pa',
# zfactor_values = p0)

    error_flag = cmor.zfactor(
        zaxis_id=ilev,
        zfactor_name='b',
        axis_ids=numpy.array((ilev, )),
        zfactor_values=b_coeff,
        zfactor_bounds=b_coeff_bnds)

# error_flag = cmor.zfactor(
# zaxis_id=ilev,
# zfactor_name='lev',
##         axis_ids= numpy.array(( ilev, )),
# units='m',
##         zfactor_values = a_coeff,
# zfactor_bounds = a_coeff_bnds )

    data2d = numpy.random.random((180, 360)).astype('f') * 8000

    zfactor_id = cmor.zfactor(
        zaxis_id=ilev,
        zfactor_name='orog',
        axis_ids=numpy.array((ilon, ilat)),
        units='m',
        zfactor_values=data2d)
else:
    print('yep working case')
    ilev = cmor.axis(
        table_entry='standard_sigma',
        units='1',
        length=lev,
        coord_vals=zlevs,
        cell_bounds=zlev_bnds)

    p0 = 0.5E4
    a_coeff = numpy.array((0.2, 0.4, 0.6, 0.8, 0.95))
    b_coeff = numpy.array((0.0, 0.1, 0.2, 0.5, 0.8))

    a_coeff_bnds = numpy.array((0., .3, .5, .7, .9, 1.))
    b_coeff_bnds = numpy.array((0., .05, .15, .35, .65, 1.))

    error_flag = cmor.zfactor(
        zaxis_id=ilev,
        zfactor_name='ptop',
        units='Pa',
        zfactor_values=p0)

    error_flag = cmor.zfactor(
        zaxis_id=ilev,
        zfactor_name='sigma',
        axis_ids=numpy.array((ilev, )),
        zfactor_values=a_coeff,
        zfactor_bounds=a_coeff_bnds)

    data2d = numpy.random.random((180, 360)).astype('f') - 97000.

    zfactor_id = cmor.zfactor(
        zaxis_id=ilev,
        zfactor_name='ps',
        axis_ids=numpy.array((ilon, ilat, itim)),
        units='Pa')

print("ILEV is:", ilev)
var3d_ids = cmor.variable(
    table_entry='concdust',
    units='kg m-3',
    axis_ids=numpy.array((ilev, ilon, ilat, itim)),
    missing_value=1.0e28,
    original_name='cocoa is good, but concoa is better')


for it in range(ntimes):

    time = numpy.array((it))
    bnds_time = numpy.array((it, it + 1))
    data3d = numpy.random.random((lev, 360, 180)).astype('f') * 40.

    error_flag = cmor.write(
        var_id=var3d_ids,
        data=data3d,
        ntimes_passed=1,
        time_vals=time,
        time_bnds=bnds_time)


error_flag = cmor.close()



import cmor
import numpy
import sys
import os
from time import localtime, strftime
today = strftime("%Y%m%d", localtime())


try:
    import cdms2
    cdms2.setNetcdfShuffleFlag(0)
    cdms2.setNetcdfDeflateFlag(0)
    cdms2.setNetcdfDeflateLevelFlag(0)
except BaseException:
    print("This test code needs a recent cdms2 interface for i/0")
    sys.exit()

level = 3
shuffle = 1
cmor.setup(
    inpath="Tables",
    set_verbosity=cmor.CMOR_NORMAL,
    netcdf_file_action=cmor.CMOR_REPLACE_4,
    exit_control=cmor.CMOR_EXIT_ON_MAJOR)
cmor.dataset_json("Test/CMOR_input_example.json")

tables = []
tables.append(cmor.load_table("CMIP6_Amon.json"))
print('Tables ids:', tables)


# read in data, just one slice
f = cdms2.open('data/tas_ccsr-95a.xml')
s = f("tas", time=slice(0, 12), squeeze=1)

ntimes = 12
varout = 'tas'

myaxes = numpy.arange(10)
myvars = numpy.arange(10)
myaxes[0] = cmor.axis(table_entry='latitude',
                      units='degrees_north',
                      coord_vals=s.getLatitude()[:], cell_bounds=s.getLatitude().getBounds())
myaxes[1] = cmor.axis(table_entry='longitude',
                      units='degrees_north',
                      coord_vals=s.getLongitude()[:], cell_bounds=s.getLongitude().getBounds())


myaxes[2] = cmor.axis(table_entry='time',
                      units=s.getTime().units,
                      coord_vals=s.getTime()[:], cell_bounds=s.getTime().getBounds())

pass_axes = [myaxes[2], myaxes[0], myaxes[1]]

myvars[0] = cmor.variable(table_entry=varout,
                          units=s.units,
                          axis_ids=pass_axes,
                          original_name=s.id,
                          history='no history',
                          comment='testing speed'
                          )
cmor.set_deflate(myvars[0], shuffle, 1, level)

import time
import MV2
st = time.time()
totcmor = 0
totcdms = 0
maxcmor = 0
mincmor = 1000
maxcdms = 0
mincdms = 1000
c0 = st
f = cdms2.open("Test/crap.nc", "w")
# print 'Time:',i
print(s.filled().shape)
cmor.write(myvars[0], s.filled(), ntimes_passed=ntimes)
c = time.time()
print('cmor write time:', c - c0)
totcmor += c - c0
if maxcmor < c - c0:
    maxcmor = c - c0
if mincmor > c - c0:
    mincmor = c - c0
c0 = c
f.write(s, id=varout)
c = time.time()
print('cdms time:', c - c0)
totcdms += c - c0
if maxcdms < c - c0:
    maxcdms = c - c0
if mincdms > c - c0:
    mincdms = c - c0
c0 = c
f.close()
cmor.close()

import cdtime
import os
ltime = cdtime.reltime(ntimes - 1, 'month since 1980').tocomp()
#lcmor = os.stat("CMIP6/CMIP/CSIRO-BOM/NICAM/piControl/r1i1p1f1/Amon/tas/gn/v%s/tas_Amon_piControl_NICAM_r1i1p1f1_gn_197901-197912.nc"%(today))[6]
lcmor = os.stat(
    "CMIP6/CMIP6/ISMIP6/PCMDI/PCMDI-test-1-0/piControl-withism/r11i1p1f1/Amon/tas/gr/v%s/tas_Amon_PCMDI-test-1-0_piControl-withism_r11i1p1f1_gr_197901-197912.nc" %
    (today))[6]
print('level:', level, "shuffle:", shuffle)
print('total cmor:', totcmor, mincmor, totcmor / ntimes, maxcmor, lcmor)
lcdms = os.stat("Test/crap.nc")[6]
print('total cdms:', totcdms, mincdms, totcdms / ntimes, maxcdms, lcdms)
print('Size diff:', float(lcmor) / float(lcdms))
print('speed diff:', totcmor / totcdms)

if os.path.exists("summary.txt"):
    f = open("summary.txt")
    s = f.read()
    f.close()
    dic = eval(s)
else:
    dic = {}

dic[(level, shuffle)] = (float(lcmor) / float(lcdms), totcmor / totcdms)

for i in range(10):
    a = dic.get((i, 0), "N/A")
    b = dic.get((i, 1), "N/A")
    print('Level: ', i, "no suffle:", a, "shuffle", b)
f = open("summary.txt", "w")
f.write(repr(dic))
f.close()



import cmor


def path_test():
    cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)

    cmor.dataset_json("Test/CMOR_input_example.json")

    table = 'CMIP6_Amon.json'
    cmor.load_table(table)
    axes = [{'table_entry': 'time',
             'units': 'days since 2000-01-01 00:00:00',
             'coord_vals': [15],
             'cell_bounds': [0, 30]
             },
            {'table_entry': 'latitude',
             'units': 'degrees_north',
             'coord_vals': [0],
             'cell_bounds': [-1, 1]},
            {'table_entry': 'longitude',
             'units': 'degrees_east',
             'coord_vals': [90],
             'cell_bounds': [89, 91]},
            ]

    axis_ids = list()
    for axis in axes:
        axis_id = cmor.axis(**axis)
        axis_ids.append(axis_id)
    varid = cmor.variable('ts', 'K', axis_ids)
    cmor.write(varid, [275])
    path = cmor.close(varid, file_name=True)

    print(path)


if __name__ == '__main__':
    path_test()



import json
import cmor
import unittest
import numpy

from netCDF4 import Dataset

CMIP7_TABLES_PATH = "cmip7-cmor-tables/tables"
CV_PATH = "TestTables/CMIP7_CV.json"

USER_INPUT = {
    "_AXIS_ENTRY_FILE": "CMIP7_coordinate.json",
    "_FORMULA_VAR_FILE": "CMIP7_formula_terms.json",
    "_cmip7_option": 1,
    "_controlled_vocabulary_file": None,
    "activity_id": "CMIP",
    "branch_time_in_child": 30.0,
    "branch_time_in_parent": 10800.0,
    "calendar": "360_day",
    "cv_version": "6.2.19.0",
    "drs_specs": "MIP-DRS7",
    "experiment_id": "piControl",
    "forcing_index": "f30",
    "grid_label": "gn",
    "initialization_index": "i000001d",
    "institution_id": "PCMDI",
    "license_id": "CC BY 4.0",
    "nominal_resolution": "250 km",
    "outpath": ".",
    "parent_mip_era": "CMIP7",
    "parent_time_units": "days since 1850-01-01",
    "parent_activity_id": "CMIP",
    "parent_source_id": "PCMDI-test-1-0",
    "parent_experiment_id": "piControl",
    "parent_variant_label": "r1i1p1f3",
    "physics_index": "p1",
    "realization_index": "r009",
    "source_id": "PCMDI-test-1-0",
    "tracking_prefix": "hdl:21.14100",
    "host_collection": "CMIP7",
    "frequency": "mon",
    "region": "glb",
    "archive_id": "WCRP",
    "output_path_template": "<activity_id><source_id><experiment_id><member_id><variable_id><branding_suffix><grid_label>",
    "output_file_template": "<variable_id><branding_suffix><frequency><region><grid_label><source_id><experiment_id><variant_label>",
}


class TestLicenseAttributes(unittest.TestCase):
    def setUp(self):
        """
        Write out a simple file using CMOR
        """
        # Set up CMOR
        cmor.setup(inpath=CMIP7_TABLES_PATH, netcdf_file_action=cmor.CMOR_REPLACE)

        # Add 'license_id' and 'license_url' to required attributes of CV
        updated_cv_path = "TestTables/CMIP7_CV_license_attrs.json"
        with open(CV_PATH, "r") as cv_infile:
            cv = json.load(cv_infile)
            cv["CV"]["required_global_attributes"].append("license_id")
            cv["CV"]["required_global_attributes"].append("license_url")
            with open(updated_cv_path, "w") as cv_outfile:
                json.dump(cv, cv_outfile, sort_keys=True, indent=4)

        # Define dataset using USER_INPUT
        USER_INPUT["_controlled_vocabulary_file"] = updated_cv_path
        with open("Test/input_cmip7.json", "w") as input_file_handle:
            json.dump(USER_INPUT, input_file_handle, sort_keys=True, indent=4)

        # read dataset info
        error_flag = cmor.dataset_json("Test/input_cmip7.json")
        if error_flag:
            raise RuntimeError("CMOR dataset_json call failed")

    def test_cmip7_with_license_id_and_url(self):
        tos = numpy.array([27, 27, 27, 27,
                           27, 27, 27, 27,
                           27, 27, 27, 27,
                           27, 27, 27, 27,
                           27, 27, 27, 27,
                           27, 27, 27, 27
                           ])
        tos.shape = (2, 3, 4)
        lat = numpy.array([10, 20, 30])
        lat_bnds = numpy.array([5, 15, 25, 35])
        lon = numpy.array([0, 90, 180, 270])
        lon_bnds = numpy.array([-45, 45,
                                135,
                                225,
                                315
                                ])
        time = numpy.array([15.5, 45])
        time_bnds = numpy.array([0, 31, 60])
        cmor.load_table("CMIP7_ocean.json")
        cmorlat = cmor.axis("latitude",
                            coord_vals=lat,
                            cell_bounds=lat_bnds,
                            units="degrees_north")
        cmorlon = cmor.axis("longitude",
                            coord_vals=lon,
                            cell_bounds=lon_bnds,
                            units="degrees_east")
        cmortime = cmor.axis("time",
                             coord_vals=time,
                             cell_bounds=time_bnds,
                             units="days since 2018")
        axes = [cmortime, cmorlat, cmorlon]
        cmortos = cmor.variable("tos_tavg-u-hxy-sea", "degC", axes)
        self.assertEqual(cmor.write(cmortos, tos), 0)
        filename = cmor.close(cmortos, file_name=True)
        self.assertEqual(cmor.close(), 0)

        ds = Dataset(filename)
        attrs = ds.ncattrs()
        test_attrs = {
            'branding_suffix': 'tavg-u-hxy-sea',
            'temporal_label': 'tavg',
            'vertical_label': 'u',
            'horizontal_label': 'hxy',
            'area_label': 'sea',
            'region': 'glb',
            'frequency': 'mon',
            'archive_id': 'WCRP',
            'mip_era': 'CMIP7',
            'data_specs_version': 'CMIP-7.0.0.0',
            'host_collection': 'CMIP7',
        }

        for attr, val in test_attrs.items():
            self.assertTrue(attr in attrs)
            self.assertEqual(val, ds.getncattr(attr))
        institution_id = USER_INPUT["institution_id"]
        license_id = "CC BY 4.0"
        license_type = "Creative Commons Attribution 4.0 International"
        license_url = "https://creativecommons.org/licenses/by/4.0/"
        license = \
            (f"{license_id}; CMIP7 data produced by {institution_id} is "
             f"licensed under a {license_type} License ({license_url}). "
             "Consult https://wcrp-cmip.github.io/cmip7-guidance/docs/CMIP7/"
             "Guidance_for_users for terms of "
             "use governing CMIP7 output, including citation requirements and "
             "proper acknowledgment. The data producers and data providers "
             "make no warranty, either express or implied, including, but not "
             "limited to, warranties of merchantability and fitness for a "
             "particular purpose. All liabilities arising from the supply of "
             "the information (including any liability arising in negligence) "
             "are excluded to the fullest extent permitted by law."
             )
        self.assertTrue("license" in attrs)
        self.assertTrue("license_id" in attrs)
        self.assertTrue("license_url" in attrs)
        self.assertTrue("license_type" not in attrs)
        self.assertEqual(license_id, ds.getncattr("license_id"))
        self.assertEqual(license_url, ds.getncattr("license_url"))
        self.assertEqual(license, ds.getncattr("license"))

        ds.close()


if __name__ == '__main__':
    unittest.main()
